"use strict";
var __values = (this && this.__values) || function(o) {
    var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
    if (m) return m.call(o);
    if (o && typeof o.length === "number") return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
    throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeTimestamp = exports.sanitizeSourceInfo = exports.isNonEmptyString = exports.sanitizeProperties = void 0;
var types_1 = require("./types");
function sanitizeProperties(properties, logger, logSource) {
    var e_1, _a;
    var _b;
    if (!properties) {
        return null;
    }
    if (typeof properties !== 'object') {
        logger.debug('Ignoring properties because they are not an object', logSource);
        return null;
    }
    var output = {};
    try {
        for (var _c = __values(Object.keys(properties)), _d = _c.next(); !_d.done; _d = _c.next()) {
            var key = _d.value;
            var value = properties[key];
            if (!(0, types_1.isPropertyValue)(value)) {
                logger.debug("Ignoring property ".concat(key, " because the value ").concat(((_b = value === null || value === void 0 ? void 0 : value.toString) === null || _b === void 0 ? void 0 : _b.call(value)) || value, " is not a valid property type"), logSource);
                continue;
            }
            output[key] = value.toString();
        }
    }
    catch (e_1_1) { e_1 = { error: e_1_1 }; }
    finally {
        try {
            if (_d && !_d.done && (_a = _c.return)) _a.call(_c);
        }
        finally { if (e_1) throw e_1.error; }
    }
    return output;
}
exports.sanitizeProperties = sanitizeProperties;
function isNonEmptyString(value) {
    return value && typeof value === 'string';
}
exports.isNonEmptyString = isNonEmptyString;
function sanitizeSourceInfo(source, logger, logSource) {
    if (!source) {
        return null;
    }
    if (!isNonEmptyString(source.name)) {
        logger.debug('Source will be ignored because name was omitted.', logSource);
        return null;
    }
    if (!isNonEmptyString(source.version)) {
        logger.debug('Source will be ignored because version was omitted.', logSource);
        return null;
    }
    if (!isNonEmptyString(source.platform)) {
        logger.debug('Source will be ignored because platform was omitted.', logSource);
        return null;
    }
    var copy = {
        name: source.name,
        version: source.version,
        platform: source.platform,
    };
    var properties = sanitizeProperties(source.properties, logger, logSource);
    if (properties) {
        copy.properties = properties;
    }
    return copy;
}
exports.sanitizeSourceInfo = sanitizeSourceInfo;
function sanitizeTimestamp(value, logger, logSource) {
    if (!value) {
        return null;
    }
    if (typeof value.getTime !== 'function') {
        logger.debug('Timestamp will be ignored because it is not a date.', logSource);
        return null;
    }
    return value.getTime();
}
exports.sanitizeTimestamp = sanitizeTimestamp;
